Re: [StGit PATCH 2/2] Reuse the same temp index in a transaction
- From
- Catalin Marinas <catalin.marinas@gmail.com>
- Date
- Jul 12, 2008, 10:24 UTC
- Message-ID
- <b0943d9e0807120324l7674c010w9a8e4a0bbdeeee65@mail.gmail.com>
- In-Reply-To
- <20080702061314.11361.28297.stgit@yoghurt>
2008/7/2 Karl Hasselström <kha@treskal.com>:
Show 12 quoted lines
> Instead of making a new temp index every time we need one, just keep > reusing the same one. And keep track of which tree is currently stored > in it -- if we do several consecutive successful pushes, it's always > going to be the "right" tree so that we don't have to call read-tree > before each patch application. > > The motivation behind this change is of course that it makes things > faster. > > (The same simple test as in the previous patch -- pushing 250 patches > in a 32k-file repository, with one file-level merge necessary per push > -- went from 0.36 to 0.19 seconds per patch with this patch applied.)
That's an impressive improvement (together with the previous patch). Is this with the new patch log infrastructure?
Thanks.
-- Catalin